pub struct ServiceFeeEvent {
pub amazon_order_id: Option<String>,
pub fee_reason: Option<String>,
pub fee_list: Option<Vec<FeeComponent>>,
pub seller_sku: Option<String>,
pub fn_sku: Option<String>,
pub fee_description: Option<String>,
pub ASIN: Option<String>,
}Expand description
ServiceFeeEvent : A service fee on the seller’s account.
Fields
amazon_order_id: Option<String>An Amazon-defined identifier for an order.
fee_reason: Option<String>A short description of the service fee reason.
fee_list: Option<Vec<FeeComponent>>A list of fee component information.
seller_sku: Option<String>The seller SKU of the item. The seller SKU is qualified by the seller’s seller ID, which is included with every call to the Selling Partner API.
fn_sku: Option<String>A unique identifier assigned by Amazon to products stored in and fulfilled from an Amazon fulfillment center.
fee_description: Option<String>A short description of the service fee event.
ASIN: Option<String>The Amazon Standard Identification Number (ASIN) of the item.
Implementations
sourceimpl ServiceFeeEvent
impl ServiceFeeEvent
sourcepub fn new() -> ServiceFeeEvent
pub fn new() -> ServiceFeeEvent
A service fee on the seller’s account.